==> jc-1.4.0.tar.gz: gnu/xml/pipeline/PipelineFactory.h <==
// public class gnu.xml.pipeline.PipelineFactory

// class file dependencies
// @dep_class 9c383a472c717cf6 gnu_xml_pipeline_PipelineFactory
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory_H_
#define _JC_gnu_xml_pipeline_PipelineFactory_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$refs	_jc_gnu_xml_pipeline_PipelineFactory$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$object	_jc_gnu_xml_pipeline_PipelineFactory$object;

typedef struct _jc_gnu_xml_pipeline_PipelineFactory$fields_struct	_jc_gnu_xml_pipeline_PipelineFactory$fields_struct;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vmethods	_jc_gnu_xml_pipeline_PipelineFactory$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vtable	_jc_gnu_xml_pipeline_PipelineFactory$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vtype	_jc_gnu_xml_pipeline_PipelineFactory$vtype;

// Class fields structure
struct _jc_gnu_xml_pipeline_PipelineFactory$fields_struct {
	_jc_object_array	*builtinStages;
};
extern _jc_gnu_xml_pipeline_PipelineFactory$fields_struct _jc_gnu_xml_pipeline_PipelineFactory$class_fields;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *);

// Virtual methods
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parsePipeline$3c5dd921a9bf2427(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object *);
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parsePipeline$2434f9d348be3b24(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object_array *, struct _jc_object *);
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parseStage$6fc23712e08f8295(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parsePipeline$3c5dd921a9bf2427;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parsePipeline$2434f9d348be3b24;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parseStage$6fc23712e08f8295;

// Static methods
extern void _jc_gnu_xml_pipeline_PipelineFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_object_array *_jc_gnu_xml_pipeline_PipelineFactory$method$access__240$fb48486de9b85693(_jc_env *);
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$e0c3006078af79a7(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$ac535bbc0aac406e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$989b4d016b10b3e3(_jc_env *, struct _jc_object_array *, struct _jc_object *);

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory$vmethods {
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*(*parsePipeline$3c5dd921a9bf2427)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object *);
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*(*parsePipeline$2434f9d348be3b24)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object_array *, struct _jc_object *);
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	*(*parseStage$6fc23712e08f8295)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory$vmethods	gnu_xml_pipeline_PipelineFactory;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory$sub_refs {
	_jc_object_array	*tokens;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory$refs {
    _jc_gnu_xml_pipeline_PipelineFactory$sub_refs	gnu_xml_pipeline_PipelineFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs	gnu_xml_pipeline_PipelineFactory;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory$object {
	_jc_gnu_xml_pipeline_PipelineFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory$vtype _jc_gnu_xml_pipeline_PipelineFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/PipelineFactory.h <==
// public class gnu.xml.pipeline.PipelineFactory

// class file dependencies
// @dep_class 9c383a472c717cf6 gnu_xml_pipeline_PipelineFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_PipelineFactory_H_
#define _JC_gnu_xml_pipeline_PipelineFactory_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object;
struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$sub_refs	_jc_gnu_xml_pipeline_PipelineFactory$sub_refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs	_jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$refs	_jc_gnu_xml_pipeline_PipelineFactory$refs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$nonrefs	_jc_gnu_xml_pipeline_PipelineFactory$nonrefs;
typedef struct _jc_gnu_xml_pipeline_PipelineFactory$object	_jc_gnu_xml_pipeline_PipelineFactory$object;

typedef struct _jc_gnu_xml_pipeline_PipelineFactory$fields_struct	_jc_gnu_xml_pipeline_PipelineFactory$fields_struct;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vmethods	_jc_gnu_xml_pipeline_PipelineFactory$vmethods;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vtable	_jc_gnu_xml_pipeline_PipelineFactory$vtable;
typedef const struct _jc_gnu_xml_pipeline_PipelineFactory$vtype	_jc_gnu_xml_pipeline_PipelineFactory$vtype;

// Class fields structure
struct _jc_gnu_xml_pipeline_PipelineFactory$fields_struct {
	_jc_object_array	*builtinStages;
};
extern _jc_gnu_xml_pipeline_PipelineFactory$fields_struct _jc_gnu_xml_pipeline_PipelineFactory$class_fields;

// Constructors
extern void _jc_gnu_xml_pipeline_PipelineFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parsePipeline$3c5dd921a9bf2427(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parsePipeline$2434f9d348be3b24(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object *_jc_gnu_xml_pipeline_PipelineFactory$method$parseStage$6fc23712e08f8295(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parsePipeline$3c5dd921a9bf2427;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parsePipeline$2434f9d348be3b24;
extern _jc_method _jc_gnu_xml_pipeline_PipelineFactory$method_info$parseStage$6fc23712e08f8295;

// Static methods
extern void _jc_gnu_xml_pipeline_PipelineFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_xml_pipeline_PipelineFactory$method$access__240$fb48486de9b85693(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$e0c3006078af79a7(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$ac535bbc0aac406e(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_pipeline_PipelineFactory$method$createPipeline$989b4d016b10b3e3(_jc_env *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_PipelineFactory$vmethods {
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*(*parsePipeline$3c5dd921a9bf2427)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Pipeline$object	*(*parsePipeline$2434f9d348be3b24)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_pipeline_PipelineFactory__24Stage$object	*(*parseStage$6fc23712e08f8295)(_jc_env *, struct _jc_gnu_xml_pipeline_PipelineFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_PipelineFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_PipelineFactory$vmethods	gnu_xml_pipeline_PipelineFactory;
};

// Vtype
struct _jc_gnu_xml_pipeline_PipelineFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_PipelineFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory$sub_refs {
	_jc_object_array	*tokens;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory$refs {
    _jc_gnu_xml_pipeline_PipelineFactory$sub_refs	gnu_xml_pipeline_PipelineFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_PipelineFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_PipelineFactory$sub_nonrefs	gnu_xml_pipeline_PipelineFactory;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_PipelineFactory$object {
	_jc_gnu_xml_pipeline_PipelineFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_PipelineFactory$vtype	*vtype;
	_jc_gnu_xml_pipeline_PipelineFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_PipelineFactory$vtype _jc_gnu_xml_pipeline_PipelineFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_PipelineFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_PipelineFactory$class_object;

#endif	/* _JC_gnu_xml_pipeline_PipelineFactory_H_ */
